@@ -5,7 +5,7 @@ int main(int argc, char* argv[])
 {
 	PsimagLite::PsiApp psiApp("internode", &argc, &argv, 1);
 	if (argc < 2) {
-		std::cerr<<"USAGE "<<argv[0]<<" number\n";
+		std::cerr << "USAGE " << argv[0] << " number\n";
 		return 1;
 	}
 
@@ -13,21 +13,23 @@ int main(int argc, char* argv[])
 
 	// original
 	for (SizeType i = 0; i < n; ++i) {
-		std::cout<<i;
+		std::cout << i;
 	}
 
-	std::cout<<"\n--------------------------\n";
+	std::cout << "\n--------------------------\n";
 
-	//lambda
+	// lambda
 	PsimagLite::InterNode<> internode(PsimagLite::MPI::COMM_WORLD);
 
-	internode.parallelFor(0, n, [](SizeType i, SizeType){std::cout << i;});
-	std::cout<<"\n--------------------------\n";
+	internode.parallelFor(0, n, [](SizeType i, SizeType) { std::cout << i; });
+	std::cout << "\n--------------------------\n";
 	size_t len = 1024;
 	char* name = new char[len + 1];
 	int x = gethostname(name, len);
-	if (x != 0) std::cerr<<argv[0]<<": Could not gethostname\n";
-	else std::cout<<name<<"\n";
-	delete [] name;
+	if (x != 0)
+		std::cerr << argv[0] << ": Could not gethostname\n";
+	else
+		std::cout << name << "\n";
+	delete[] name;
 	name = nullptr;
 }
