@@ -1,6 +1,6 @@
+#include "CrsMatrix.h"
 #include "LanczosSolver.h"
 #include "Matrix.h"
-#include "CrsMatrix.h"
 #include "PsimagLite.h"
 
 int main()
@@ -12,10 +12,11 @@ int main()
 	int n = 8;
 	PsimagLite::Matrix<ComplexType> m(n, n);
 	// fill m
-	for (int i = 0; i < n; ++i) m(i,i) = 1.0;
-	m(1,2) = ComplexType(0.0,0.5);
-	m(2,1) = PsimagLite::conj(m(1,2));
-	m(3,5) = m(5,3) = -1.5;
+	for (int i = 0; i < n; ++i)
+		m(i, i) = 1.0;
+	m(1, 2) = ComplexType(0.0, 0.5);
+	m(2, 1) = PsimagLite::conj(m(1, 2));
+	m(3, 5) = m(5, 3) = -1.5;
 
 	PsimagLite::CrsMatrix<ComplexType> msparse(m);
 
@@ -23,7 +24,9 @@ int main()
 	params.lotaMemory = true;
 
 	PsimagLite::LanczosSolver<SolverParametersType,
-	        PsimagLite::CrsMatrix<ComplexType>,VectorType> lanczosSolver(msparse, params);
+	    PsimagLite::CrsMatrix<ComplexType>,
+	    VectorType>
+	    lanczosSolver(msparse, params);
 
 	double e = 0;
 	VectorType z(n, 0.0);
@@ -31,6 +34,6 @@ int main()
 	PsimagLite::fillRandom(initial);
 	lanczosSolver.computeOneState(e, z, initial, 0);
 
-	std::cout<<"energy="<<e<<"\n";
-	std::cout<<z<<"\n";
+	std::cout << "energy=" << e << "\n";
+	std::cout << z << "\n";
 }
