@@ -1,10 +1,11 @@
+#include "LoadBalancerWeights.h"
 #include "Parallelizer2.h"
 #include "Vector.h"
-#include "LoadBalancerWeights.h"
 
 int main(int argc, char** argv)
 {
-	if (argc < 3) return 1;
+	if (argc < 3)
+		return 1;
 
 	const SizeType n = atoi(argv[1]);
 	const SizeType threads = atoi(argv[2]);
@@ -13,12 +14,9 @@ int main(int argc, char** argv)
 
 	PsimagLite::Parallelizer2<> parallelizer(threads);
 
-	std::cout<<"Testing Parallelizer2 with "<<parallelizer.name();
-	std::cout<<" and "<<parallelizer.numberOfThreads()<<" threads.\n";
-	parallelizer.parallelFor(0, n, [&v](SizeType i, SizeType)
-	{
-		v[i] = i + 42; 
-	});
+	std::cout << "Testing Parallelizer2 with " << parallelizer.name();
+	std::cout << " and " << parallelizer.numberOfThreads() << " threads.\n";
+	parallelizer.parallelFor(0, n, [&v](SizeType i, SizeType) { v[i] = i + 42; });
 
 	/*
 	for (SizeType i = 0; i < n; ++i) {
@@ -26,5 +24,5 @@ int main(int argc, char** argv)
 	}
 	*/
 
-	std::cout<<v[0]<<" "<<v[n - 1]<<"\n";
+	std::cout << v[0] << " " << v[n - 1] << "\n";
 }
