@@ -3,10 +3,11 @@
 
 int main(int argc, char** argv)
 {
-	if (argc < 3) return 1;
+	if (argc < 3)
+		return 1;
 	PsimagLite::String predicate(argv[1]);
 
-	PsimagLite::PredicateAwesome<>::replaceAll(predicate, "c", "5");
+	PsimagLite::replaceAll(predicate, "c", "5");
 	PsimagLite::PredicateAwesome<> pAwesome(predicate);
-	std::cout<<pAwesome.isTrue("l", atoi(argv[2]));
+	std::cout << pAwesome.isTrue("l", atoi(argv[2]));
 }
