@@ -1,14 +1,16 @@
 #ifndef _AINUR_EMPTY_H_
 #define _AINUR_EMPTY_H_
-#include <iostream>
-#include <fstream>
-#include "Vector.h"
-#include "TypeToString.h"
 #include "PsimagLite.h"
+#include "TypeToString.h"
+#include "Vector.h"
+#include <fstream>
+#include <iostream>
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-class Ainur {
+class Ainur
+{
 
 public:
 
@@ -22,41 +24,38 @@ public:
 
 	const String& prefix() const { return dummy_; }
 
-	void printUnused(std::ostream& os) const
-	{
-		errorMessage();
-	}
+	void printUnused(std::ostream& os) const { errorMessage(); }
 
-	void printAll(std::ostream& os) const
-	{
-		errorMessage();
-	}
+	void printAll(std::ostream& os) const { errorMessage(); }
 
-	template<typename SomeType>
+	template <typename SomeType>
 	void readValue(SomeType& t, String label) const
 	{
 		errorMessage();
 	}
 
-	template<typename SomeMapType>
+	std::string resolve(const std::string& str) const
+	{
+		errorMessage();
+		return "";
+	}
+
+	template <typename SomeMapType>
 	void setMap(SomeMapType&) const
 	{
 		errorMessage();
 	}
 
-	void expandMacrosRecursively()
-	{
-		errorMessage();
-	}
 private:
 
 	void errorMessage() const
 	{
-		err("To use Ainur, you need boost-devel, and compile with -DUSE_BOOST\n");
+		err("To use Ainur, you need boost-devel, and compile with "
+		    "-DUSE_BOOST\n");
 	}
 
 	String dummy_;
 };
 
-}
+} // namespace PsimagLite
 #endif // _AINUR_EMPTY_H_
