@@ -1,28 +1,30 @@
 #ifndef _AINUR_SPIRIT_H_
 #define _AINUR_SPIRIT_H_
-#include "../Vector.h"
-#include "../TypeToString.h"
 #include "../PsimagLite.h"
+#include "../TypeToString.h"
+#include "../Vector.h"
+#include "AinurLexical.h"
+#include "AinurState.h"
+#include <fstream>
 #include <iostream>
 #include <string>
-#include <fstream>
-#include "AinurState.h"
-#include "AinurLexical.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-class Ainur {
+class Ainur
+{
 
 	struct Action {
 
 		Action(String name, AinurState& state)
-		    : name_(name), state_(state)
-		{}
+		    : name_(name)
+		    , state_(state)
+		{
+		}
 
 		template <typename A, typename ContextType>
-		void operator()(A& attr,
-		                ContextType& context,
-		                bool& hit) const;
+		void operator()(A& attr, ContextType& context, bool& hit) const;
 
 	private:
 
@@ -33,13 +35,13 @@ class Ainur {
 	struct Action3 {
 
 		Action3(String name, AinurState& state)
-		    : name_(name), state_(state)
-		{}
+		    : name_(name)
+		    , state_(state)
+		{
+		}
 
 		template <typename A, typename ContextType>
-		void operator()(A& attr,
-		                ContextType& context,
-		                bool& hit) const;
+		void operator()(A& attr, ContextType& context, bool& hit) const;
 
 	private:
 
@@ -47,10 +49,9 @@ class Ainur {
 		AinurState& state_;
 	};
 
-	struct myprint
-	{
+	struct myprint {
 		template <typename T>
-		void operator()(const T &t) const
+		void operator()(const T& t) const
 		{
 			std::cout << " --------> " << t << '\n';
 		}
@@ -68,39 +69,36 @@ public:
 
 	const String& prefix() const { return dummy_; }
 
-	void printUnused(std::ostream& os) const
-	{
-		state_.printUnused(os);
-	}
+	void printUnused(std::ostream& os) const { state_.printUnused(os); }
 
-	void printAll(std::ostream& os) const
-	{
-		state_.printAll(os);
-	}
+	void printAll(std::ostream& os) const { state_.printAll(os); }
 
-	template<typename SomeType>
+	template <typename SomeType>
 	void readValue(SomeType& t, String label) const
 	{
 		state_.readValue(t, dummy_ + label);
 	}
 
-	template<typename SomeMapType>
+	template <typename SomeMapType>
 	void setMap(SomeMapType& map) const
 	{
 		state_.setMap(map);
 	}
 
-	void expandMacrosRecursively()
+	std::string resolve(const std::string& str) const
 	{
-		state_.expandMacrosRecursively();
+		return state_.resolve(str);
 	}
 
 private:
 
-	static bool allEmpty(IteratorType first,IteratorType last)
+	void initMacros() { state_.initMacros(); }
+
+	static bool allEmpty(IteratorType first, IteratorType last)
 	{
 		for (IteratorType it = first; it != last; ++it) {
-			if (AinurLexical::isEmptyChar(*it)) continue;
+			if (AinurLexical::isEmptyChar(*it))
+				continue;
 			return false;
 		}
 
@@ -111,5 +109,5 @@ private:
 	AinurState state_;
 }; // class AinurSpirit
 
-}
+} // namespace PsimagLite
 #endif // _AINUR_SPIRIT_H_
