@@ -3,42 +3,32 @@
 #include "PsimagLite.h"
 #include "QuasiCanonical.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-template<typename ItemSpecType>
-class AssignAndDestroy {
+template <typename ItemSpecType>
+class AssignAndDestroy
+{
 
 public:
 
 	typedef typename ItemSpecType::ResultType T;
 	typedef typename ItemSpecType::ComplexOrRealType ComplexOrRealType;
 
-	AssignAndDestroy(const T& t) : t_(t) {}
-
-	void assignBackward(T& t2) const
+	AssignAndDestroy(const T& t)
+	    : t_(t)
 	{
-		t2 = t_;
 	}
 
-	void assign(const AssignAndDestroy& t2)
-	{
-		t_ = t2.t_;
-	}
+	void assignBackward(T& t2) const { t2 = t_; }
 
-	void plusBackward(T& t2) const
-	{
-		t2 += t_;
-	}
+	void assign(const AssignAndDestroy& t2) { t_ = t2.t_; }
 
-	void multiply(const AssignAndDestroy& t2)
-	{
-		t_ *= (t2.t_);
-	}
+	void plusBackward(T& t2) const { t2 += t_; }
 
-	void multiplyScalar(const ComplexOrRealType& scalar)
-	{
-		t_ *= scalar;
-	}
+	void multiply(const AssignAndDestroy& t2) { t_ *= (t2.t_); }
+
+	void multiplyScalar(const ComplexOrRealType& scalar) { t_ *= scalar; }
 
 	const bool isEmpty() const { return ItemSpecType::isEmpty(t_); }
 
@@ -47,7 +37,8 @@ public:
 		return ItemSpecType::metaEqual(t_, t2);
 	}
 
-	static bool metaEqual(const AssignAndDestroy& t1, const AssignAndDestroy& t2)
+	static bool metaEqual(const AssignAndDestroy& t1,
+	    const AssignAndDestroy& t2)
 	{
 		return ItemSpecType::metaEqual(t1.t_, t2.t_);
 	}
@@ -57,9 +48,10 @@ private:
 	T t_;
 };
 
-template<typename ItemSpecType,
-         typename AssignAndDestroyType = AssignAndDestroy<ItemSpecType> >
-class CanonicalExpression {
+template <typename ItemSpecType,
+    typename AssignAndDestroyType = AssignAndDestroy<ItemSpecType>>
+class CanonicalExpression
+{
 
 	typedef typename ItemSpecType::ResultType ResultType;
 	typedef typename ItemSpecType::ComplexOrRealType ComplexOrRealType;
@@ -72,42 +64,41 @@ public:
 
 	CanonicalExpression(const ItemSpecType& itemSpec)
 	    : itemSpec_(itemSpec)
-	{}
+	{
+	}
 
-	bool operator()(ResultType& result,
-	                String expr,
-	                const ResultType& resultEmpty,
-	                AuxiliaryType& aux) const
+	bool operator()(ResultType& result, String expr, const ResultType& resultEmpty, AuxiliaryType& aux) const
 	{
 		// canonical expressions only for now
 		// expr --> exprCanonical
 		QuasiCanonicalType quasiCanonical(expr);
-		//String exprCanonical = expr; // canonicalize here
-		//VectorStringType vecStr;
+		// String exprCanonical = expr; // canonicalize here
+		// VectorStringType vecStr;
 		const SizeType numberOfTerms = quasiCanonical.numberOfTerms();
 
-
 		for (SizeType i = 0; i < numberOfTerms; ++i) {
-			AssignAndDestroyType assignAndDestroy(resultEmpty);// t_ = resultEmpty
-			bool isNotEmpty = procCanonicalTerm(assignAndDestroy, quasiCanonical, i, aux);
+			AssignAndDestroyType assignAndDestroy(
+			    resultEmpty); // t_ = resultEmpty
+			bool isNotEmpty = procCanonicalTerm(
+			    assignAndDestroy, quasiCanonical, i, aux);
 			if (!isNotEmpty)
 				continue;
 			if (!assignAndDestroy.metaEqual(result))
 				err("CanonicalExpression: metas not equal\n");
 
 			if (i == 0)
-				assignAndDestroy.assignBackward(result);  // result = t_;
+				assignAndDestroy.assignBackward(
+				    result); // result = t_;
 			else
-				assignAndDestroy.plusBackward(result); // result += t_;
+				assignAndDestroy.plusBackward(
+				    result); // result += t_;
 		}
 
 		return (ItemSpecType::isEmpty(result)) ? false : true;
 	}
 
-	template<typename T>
-	static std::pair<bool, String> replaceAll(String str,
-	                                          String label,
-	                                          T value)
+	template <typename T>
+	static std::pair<bool, String> replaceAll(String str, String label, T value)
 	{
 		std::pair<bool, String> boolString(true, str);
 
@@ -120,19 +111,19 @@ public:
 		return std::pair<bool, String>(retFlag, boolString.second);
 	}
 
-	template<typename T>
-	static std::pair<bool, String> replaceOne(String str,
-	                                          String label,
-	                                          T value)
+	template <typename T>
+	static std::pair<bool, String> replaceOne(String str, String label, T value)
 	{
 		// find one occurrence
 		size_t x = str.find(label);
-		if (x == String::npos) return std::pair<bool, String>(false, str);
+		if (x == String::npos)
+			return std::pair<bool, String>(false, str);
 
 		String ret = (x == 0) ? "" : str.substr(0, x);
 		ret += ttos(value);
 
-		ret += str.substr(x + label.length(), str.length() - x - label.length());
+		ret += str.substr(x + label.length(),
+		    str.length() - x - label.length());
 
 		return std::pair<bool, String>(true, ret);
 	}
@@ -140,9 +131,9 @@ public:
 private:
 
 	bool procCanonicalTerm(AssignAndDestroyType& assignAndDestroy,
-	                       QuasiCanonicalType& quasiCanonical,
-	                       SizeType ind,
-	                       AuxiliaryType& aux) const
+	    QuasiCanonicalType& quasiCanonical,
+	    SizeType ind,
+	    AuxiliaryType& aux) const
 	{
 		String termCanonical = quasiCanonical.term(ind);
 		ComplexOrRealType factor = 1.0;
@@ -161,10 +152,10 @@ private:
 	}
 
 	void procCanonicalFactor(AssignAndDestroyType& prev,
-	                         ComplexOrRealType& factor,
-	                         String termStr,
-	                         QuasiCanonicalType& quasiCanonical,
-	                         AuxiliaryType& aux) const
+	    ComplexOrRealType& factor,
+	    String termStr,
+	    QuasiCanonicalType& quasiCanonical,
+	    AuxiliaryType& aux) const
 	{
 		bool isCaScalar = QuasiCanonicalType::isRealScalar(termStr);
 		if (isCaScalar) {
