@@ -2,19 +2,25 @@
 #define CMPLX_OR_REAL_H
 #include "Vector.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-template<typename RealType, int>
-class CpmlxOrReal {};
+template <typename RealType, int>
+class CpmlxOrReal
+{
+};
 
-template<typename RealType>
-class CpmlxOrReal<RealType, 1> {
+template <typename RealType>
+class CpmlxOrReal<RealType, 1>
+{
 
 public:
 
 	typedef std::complex<RealType> ComplexType;
 
-	CpmlxOrReal(String t) : isImag_(false), value_(0)
+	CpmlxOrReal(String t)
+	    : isImag_(false)
+	    , value_(0)
 	{
 
 		const SizeType len = t.length();
@@ -22,7 +28,8 @@ public:
 		for (SizeType i = 0; i < len; ++i) {
 			if (t[i] == 'i') {
 				if (isImag_)
-					throw RuntimeError("More than one i found\n");
+					throw RuntimeError(
+					    "More than one i found\n");
 				isImag_ = true;
 				continue;
 			}
@@ -30,8 +37,10 @@ public:
 			buffer += t[i];
 		}
 
-		if (isImag_ && buffer == "") value_ = 1;
-		else value_ = PsimagLite::atof(buffer);
+		if (isImag_ && buffer == "")
+			value_ = 1;
+		else
+			value_ = PsimagLite::atof(buffer);
 	}
 
 	ComplexType value() const
@@ -45,16 +54,19 @@ private:
 	RealType value_;
 };
 
-template<typename RealType>
-class CpmlxOrReal<RealType, 0> {
+template <typename RealType>
+class CpmlxOrReal<RealType, 0>
+{
 
 public:
 
-	CpmlxOrReal(String t) : value_(0)
+	CpmlxOrReal(String t)
+	    : value_(0)
 	{
 		bool isComplex = (t.find("i") != String::npos);
 		if (isComplex)
-			throw RuntimeError("i \\equiv sqrt(-1) found but code path is real\n");
+			throw RuntimeError(
+			    "i \\equiv sqrt(-1) found but code path is real\n");
 		value_ = PsimagLite::atof(t);
 	}
 
@@ -65,5 +77,5 @@ private:
 	RealType value_;
 };
 
-}
+} // namespace PsimagLite
 #endif // CMPLX_OR_REAL_H
