@@ -1,9 +1,9 @@
 #include "Concurrency.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
 SizeType Concurrency::mode = 0;
 LabelDisabled Concurrency::mpiDisabled_;
 CodeSectionParams Concurrency::codeSectionParams(1);
 } // namespace PsimagLite
-
