@@ -9,7 +9,8 @@
 #include "IoNg.h"
 #endif
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
 #ifdef USE_IO_SIMPLE
 typedef PsimagLite::IoSimple IoSelector;
