@@ -4,7 +4,8 @@
 #ifndef USE_IO_SIMPLE
 
 #include "IoNgSerializer.h"
-namespace PsimagLite {
+namespace PsimagLite
+{
 
 typedef IoNgSerializer IoSerializer;
 
@@ -14,7 +15,8 @@ typedef IoNgSerializer IoSerializer;
 
 #include "IoSerializerEmpty.h"
 
-namespace  PsimagLite {
+namespace PsimagLite
+{
 
 typedef IoSerializerEmpty IoSerializer;
 
