@@ -2,22 +2,21 @@
 #define LABEL_DISABLED_H
 #include "Vector.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-class LabelDisabled {
+class LabelDisabled
+{
 
 	typedef Vector<String>::Type VectorStringType;
 
 public:
 
-	void disable(String label)
-	{
-		data_.push_back(label);
-	}
+	void disable(String label) { data_.push_back(label); }
 
 	bool operator()(String label) const
 	{
-		return (find(data_.begin(),data_.end(),label) != data_.end());
+		return (find(data_.begin(), data_.end(), label) != data_.end());
 	}
 
 private:
@@ -25,5 +24,5 @@ private:
 	VectorStringType data_;
 };
 
-}
+} // namespace PsimagLite
 #endif // LABEL_DISABLED_H
