@@ -1,18 +1,20 @@
 #ifndef LOADBALANCERDEFAULT_H
 #define LOADBALANCERDEFAULT_H
-#include "Vector.h"
 #include "Sort.h"
+#include "Vector.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-class LoadBalancerDefault {
+class LoadBalancerDefault
+{
 
 public:
 
 	typedef PsimagLite::Vector<SizeType>::Type VectorSizeType;
 
 	LoadBalancerDefault(SizeType ntasks, SizeType nthreads)
-	    : blockSize_(ntasks/nthreads)
+	    : blockSize_(ntasks / nthreads)
 	{
 		if (ntasks < nthreads && ntasks > 0) {
 			nthreads = ntasks;
@@ -20,17 +22,15 @@ public:
 		}
 
 		assert(nthreads > 0);
-		if ((ntasks % nthreads) != 0) ++blockSize_;
+		if ((ntasks % nthreads) != 0)
+			++blockSize_;
 	}
 
-	SizeType blockSize(SizeType) const
-	{
-		return blockSize_;
-	}
+	SizeType blockSize(SizeType) const { return blockSize_; }
 
 	SizeType taskNumber(SizeType threadNum, SizeType p) const
 	{
-		return p + threadNum*blockSize_;
+		return p + threadNum * blockSize_;
 	}
 
 private:
