@@ -1,6 +1,7 @@
 #include "MemResolv.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
 bool operator==(const MemoryPointer& a, const MemoryPointer& b)
 {
@@ -13,20 +14,19 @@ bool operator==(const MemoryPointer& a, const MemoryPointer& b)
 
 std::ostream& operator<<(std::ostream& os, const MemResolv& mresolv)
 {
-	os<<"MemResolvs "<<mresolv.vmptr_.size()<<"\n";
+	os << "MemResolvs " << mresolv.vmptr_.size() << "\n";
 	for (SizeType i = 0; i < mresolv.vmptr_.size(); ++i)
-		mresolv.print(os,mresolv.vmptr_[i]);
+		mresolv.print(os, mresolv.vmptr_[i]);
 
-	os<<"MemResolv garbage: "<<mresolv.garbage_.size();
+	os << "MemResolv garbage: " << mresolv.garbage_.size();
 	for (SizeType i = 0; i < mresolv.garbage_.size(); ++i) {
-		os<<reinterpret_cast<void *>(mresolv.garbage_[i]);
-		os<<" "<<mresolv.garbageSize_[i];
+		os << reinterpret_cast<void*>(mresolv.garbage_[i]);
+		os << " " << mresolv.garbageSize_[i];
 	}
 
-	os<<"\n";
+	os << "\n";
 
 	return os;
 }
 
 } // namespace PsimagLite
-
