@@ -1,6 +1,7 @@
 #include "MersenneTwister.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
 MersenneTwister::MersenneTwister(unsigned s)
     : index_(0)
@@ -9,7 +10,7 @@ MersenneTwister::MersenneTwister(unsigned s)
 }
 
 MersenneTwister::MersenneTwister(unsigned s, int rank, int)
-: index_(0)
+    : index_(0)
 {
 	seed(s);
 	int news = random();
@@ -20,32 +21,27 @@ MersenneTwister::MersenneTwister(unsigned s, int rank, int)
 	seed(news);
 }
 
-void
-MersenneTwister::seed(unsigned s)
+void MersenneTwister::seed(unsigned s)
 {
 	index_ = 0;
 	state_[0] = s;
 	for (unsigned i = 1; i < N_; ++i) {
-		unsigned tmp = state_[i-1]^(state_[i-1]>>30);	
-		state_[i] =  keepLast32BitMask_ &
-		        (1812433253 * (tmp + i));
+		unsigned tmp = state_[i - 1] ^ (state_[i - 1] >> 30);
+		state_[i] = keepLast32BitMask_ & (1812433253 * (tmp + i));
 	}
 }
 
-void
-MersenneTwister::generate()
+void MersenneTwister::generate()
 {
 	for (unsigned i = 0; i < N_; ++i) {
-		unsigned y = (state_[i] & 0x80000000) +
-		        (state_[(i+1)%N_] & 0x7fffffff);
-		state_[i] = state_[(i+397)%N_] ^ (y >> 1);
-		if (y%2 != 0)
+		unsigned y = (state_[i] & 0x80000000) + (state_[(i + 1) % N_] & 0x7fffffff);
+		state_[i] = state_[(i + 397) % N_] ^ (y >> 1);
+		if (y % 2 != 0)
 			state_[i] ^= 2567483615;
 	}
 }
 
-unsigned
-MersenneTwister::random()
+unsigned MersenneTwister::random()
 {
 	if (index_ == 0)
 		generate();
@@ -56,17 +52,15 @@ MersenneTwister::random()
 	y ^= (y << 15) & 4022730752;
 	y ^= (y >> 18);
 
-	index_ = (index_+1)%N_;
+	index_ = (index_ + 1) % N_;
 
 	return y;
 }
 
-double
-MersenneTwister::operator() ()
+double MersenneTwister::operator()()
 {
 	unsigned r = random();
-	return (static_cast<double>(r)/keepLast32BitMask_);
+	return (static_cast<double>(r) / keepLast32BitMask_);
 }
 
 } // namespace PsimagLite
-
