@@ -1,13 +1,15 @@
 #ifndef PARALLELIZER2OPENMP_H
 #define PARALLELIZER2OPENMP_H
+#include "CodeSectionParams.h"
 #include "Vector.h"
 #include <omp.h>
-#include "CodeSectionParams.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-template<typename = int>
-class Parallelizer2 {
+template <typename = int>
+class Parallelizer2
+{
 
 public:
 
@@ -17,7 +19,7 @@ public:
 		omp_set_num_threads(codeParams.npthreads);
 	}
 
-	template<typename SomeLambdaType>
+	template <typename SomeLambdaType>
 	void parallelFor(SizeType start, SizeType end, const SomeLambdaType& lambda)
 	{
 #pragma omp parallel for
@@ -25,10 +27,7 @@ public:
 			lambda(i, omp_get_thread_num());
 	}
 
-	SizeType numberOfThreads() const
-	{
-		return omp_get_num_threads();
-	}
+	SizeType numberOfThreads() const { return omp_get_num_threads(); }
 
 	String name() const { return "openmp"; }
 
@@ -36,5 +35,5 @@ private:
 
 	SizeType threads_;
 };
-}
+} // namespace PsimagLite
 #endif // PARALLELIZER2OPENMP_H
