@@ -1,22 +1,25 @@
 #ifndef PARALLELIZER2SERIAL_H
 #define PARALLELIZER2SERIAL_H
-#include "Vector.h"
 #include "CodeSectionParams.h"
+#include "Vector.h"
 
-namespace PsimagLite {
+namespace PsimagLite
+{
 
-template<typename = int>
-class Parallelizer2 {
+template <typename = int>
+class Parallelizer2
+{
 
 public:
 
 	Parallelizer2(const CodeSectionParams& codeParams)
 	{
 		if (codeParams.npthreads != 1)
-			throw RuntimeError("Please compile with -DUSE_PTHREADS\n");
+			throw RuntimeError(
+			    "Please compile with -DUSE_PTHREADS\n");
 	}
 
-	template<typename SomeLambdaType>
+	template <typename SomeLambdaType>
 	void parallelFor(SizeType start, SizeType end, const SomeLambdaType& lambda)
 	{
 		for (SizeType i = start; i < end; ++i)
@@ -27,5 +30,5 @@ public:
 
 	String name() const { return "serial"; }
 };
-}
+} // namespace PsimagLite
 #endif // PARALLELIZER2SERIAL_H
