@@ -29,19 +29,20 @@ Please see full open source license included in file LICENSE.
 #ifndef PLOT_PARAMS_H
 #define PLOT_PARAMS_H
 
-namespace PsimagLite {
-template<typename RealType>
+namespace PsimagLite
+{
+template <typename RealType>
 struct PlotParams {
 
-	PlotParams(RealType wbegin,
-	           RealType wend,
-	           RealType wstep,
-	           RealType wdelta,
-	           RealType beta1,
-	           SizeType numberOfMatsubaras1)
-	: omega1(wbegin),omega2(wend),deltaOmega(wstep),delta(wdelta),
-	  beta(beta1),numberOfMatsubaras(numberOfMatsubaras1)
-	{}
+	PlotParams(RealType wbegin, RealType wend, RealType wstep, RealType wdelta, RealType beta1, SizeType numberOfMatsubaras1)
+	    : omega1(wbegin)
+	    , omega2(wend)
+	    , deltaOmega(wstep)
+	    , delta(wdelta)
+	    , beta(beta1)
+	    , numberOfMatsubaras(numberOfMatsubaras1)
+	{
+	}
 
 	RealType omega1;
 	RealType omega2;
@@ -52,5 +53,4 @@ struct PlotParams {
 };
 } // namespace PsimagLite
 /*@}*/
-#endif  //PLOT_PARAMS_H
-
+#endif // PLOT_PARAMS_H
